/* Swfdec
 * Copyright (C) 2003-2006 David Schleef <ds@schleef.org>
 *		 2005-2006 Eric Anholt <eric@anholt.net>
 *		 2006-2008 Benjamin Otte <otte@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */

#ifndef __SWFDEC_H__
#define __SWFDEC_H__

#include <swfdec/swfdec_as_array.h>
#include <swfdec/swfdec_as_context.h>
#include <swfdec/swfdec_as_debugger.h>
#include <swfdec/swfdec_as_frame.h>
#include <swfdec/swfdec_as_function.h>
#include <swfdec/swfdec_as_native_function.h>
#include <swfdec/swfdec_as_object.h>
#include <swfdec/swfdec_as_relay.h>
#include <swfdec/swfdec_as_types.h>
#include <swfdec/swfdec_script.h>

#include <swfdec/swfdec_audio.h>
#include <swfdec/swfdec_buffer.h>
#include <swfdec/swfdec_enums.h>
#include <swfdec/swfdec_file_loader.h>
#include <swfdec/swfdec_keys.h>
#include <swfdec/swfdec_loader.h>
#include <swfdec/swfdec_player.h>
#include <swfdec/swfdec_player_scripting.h>
#include <swfdec/swfdec_rectangle.h>
#include <swfdec/swfdec_renderer.h>
#include <swfdec/swfdec_socket.h>
#include <swfdec/swfdec_stream.h>
#include <swfdec/swfdec_system.h>
#include <swfdec/swfdec_url.h>
#include <swfdec/swfdec_version.h>

#endif
